# Overview


```python

```

The goals of this library are:

* Easy-to-use API for interacting with various Search backends.
* Not coupled to any specific Search engine (Solr support initially).
* Not coupled to any web framework (i.e. Django Haystack)
* Performance improvements with AsyncIO support via aiohttp library.
* Developed with modern Python, leveraging dataclasses and f-strings
